#!/bin/sh -x

VERSION=$2
TAR=$3
PACKAGE=$(dpkg-parsechangelog | sed -n 's/^Source: //p')
DIR=../${PACKAGE}-${VERSION}

mkdir $DIR
tar -zxf $TAR -C $DIR
tar -zcf ../${PACKAGE}_${VERSION}+dfsg.orig.tar.gz --exclude *.exe $DIR

rm -rf $DIR
rm $TAR


